"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createCanvasElement = void 0;
const jsdom_1 = require("jsdom");
const skia_canvas_1 = require("skia-canvas");
const convertTypeQuality = (type, quality) => {
    switch (type) {
        case "jpg":
        case "image/jpg":
            return ["jpg", { quality: quality }];
        case "jpeg":
        case "image/jpeg":
            return ["jpeg", { quality: quality }];
        case "pdf":
        case "application/pdf":
            return ["pdf", {}];
        case "svg":
        case "image/svg":
            return ["svg", {}];
        case "png":
        case "image/png":
        default:
            return ["png", {}];
    }
};
function createCanvasElement(options) {
    const dom = new jsdom_1.JSDOM();
    const window = new skia_canvas_1.Window(options);
    const element = dom.window.document.createElement("canvas");
    const prototype = Object.getPrototypeOf(element);
    prototype.getContext = (contextId) => window.canvas.getContext(contextId);
    prototype.toDataURL = (type, quality) => {
        const [format, options] = convertTypeQuality(type, quality);
        return window.canvas.toDataURLSync(format, options);
    };
    prototype.toBlob = (callback, type, quality) => {
        const [format, options] = convertTypeQuality(type, quality);
        window.canvas
            .toBuffer(format, options)
            .then((buffer) => callback(new dom.window.Blob([buffer], { type })));
    };
    return element;
}
exports.createCanvasElement = createCanvasElement;
//# sourceMappingURL=canvas.js.map